import { Construct } from 'constructs';
import { Output } from '../../domain/output';
import { IGenericVariable } from '../../interface/variables/variable';
import { AutomationStep, AutomationStepProps } from '../automation-step';
/**
 * Properties for update variable step.
 */
export interface UpdateVariableProps extends AutomationStepProps {
    /**
     * (Required) The name of the variable to be updated. Must use format `variable:<variable name>`.
     */
    readonly variableName: string;
    /**
     * (Required) The value of the variable to be updated.
     */
    readonly variableValue: IGenericVariable;
}
/**
 * AutomationStep implementation for aws:updateVariable
 * https://docs.aws.amazon.com/systems-manager/latest/userguide/automation-action-update-variable.html
 */
export declare class UpdateVariableStep extends AutomationStep {
    readonly variableName: string;
    readonly variableValue: IGenericVariable;
    readonly action: string;
    constructor(scope: Construct, id: string, props: UpdateVariableProps);
    /**
     * No outputs emitted from update variable step
     * @returns []
     */
    listOutputs(): Output[];
    listInputs(): string[];
    toSsmEntry(): {
        [name: string]: any;
    };
}
